@@ -20,6 +20,7 @@
 #
 
 library(lsgl)
+library(methods)
 
 # warnings = errors
 options(warn=2)
@@ -38,9 +39,9 @@ B<-matrix(sample(c(rep(1,p*K*0.1),rep(0, p*K-as.integer(p*K*0.1)))),nrow=p,ncol=
 X<-matrix(rnorm(N*p,1,1),nrow=N,ncol=p)
 Y<-X%*%B+matrix(rnorm(N*K,0,1),N,K)
 
-lambda<-lsgl.lambda(X,Y, alpha=1, lambda.min=.5, intercept=FALSE)
+lambda<-lsgl::lambda(X,Y, alpha=1, lambda.min=.5, intercept=FALSE)
 
-fit <-lsgl(X,Y, alpha=1, lambda = lambda, intercept=FALSE)
+fit <-lsgl::fit(X,Y, alpha=1, lambda = lambda, intercept=FALSE)
 
 # print info
 fit
