@@ -2,7 +2,7 @@ library(lsgl)
 # warnings = errors
 options(warn=2)
 
-c_config <- sgl.c.config()
+c_config <- lsgl.c.config()
 
 if(c_config$timing) stop()
 
